Template class

Below is Tiled's documentation about how this structure is represented on XML files:

<template>

The template root element contains the saved map object and a tileset element that points to an external tileset, if the object is a tile object.

Example of a template file:

  <?xml version="1.0" encoding="UTF-8"?>
  <template>
   <tileset firstgid="1" source="desert.tsx"/>
   <object name="cactus" gid="31" width="81" height="101"/>
  </template>

Can contain at most one: <tileset>, <object>

Constructors

Template({Tileset? tileSet, TiledObject? object})
Template.parse(Parser parser)

Properties

hashCode int
The hash code for this object.
no setterinherited
object TiledObject?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tileSet Tileset?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited