clone method
Create a new atlas from this object with the intent of getting a new
SpriteBatch.
Implementation
TiledAtlas clone() => TiledAtlas._(
atlas: atlas?.clone(),
offsets: offsets,
key: key,
useAtlas: useAtlas,
);
Create a new atlas from this object with the intent of getting a new
SpriteBatch.
TiledAtlas clone() => TiledAtlas._(
atlas: atlas?.clone(),
offsets: offsets,
key: key,
useAtlas: useAtlas,
);