WangColor class

Below is Tiled's documentation about how this structure is represented on XML files:

<wangcolor> A color that can be used to define the corner and/or edge of a Wang tile.

  • name: The name of this color.
  • color: The color in #RRGGBB format (example: #c17d11).
  • tile: The tile ID of the tile representing this color.
  • probability: The relative probability that this color is chosen over others in case of multiple options. (defaults to 0)

Can contain at most one: <properties>

Constructors

WangColor({required String name, required String color, required int tile, double probability = 0, CustomProperties properties = CustomProperties.empty})
WangColor.parse(Parser parser)

Properties

color String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
probability double
getter/setter pair
properties CustomProperties
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tile int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited